@@ -7,9 +7,10 @@ use Carp;
 use Config;
 use ExtUtils::testlib;
 use Getopt::Long;
-use Test::More 0.82; #note
+use Test::More;
 use Data::Dumper;
 use File::Spec;
+use File::Temp qw(tempfile);
 use List::Util qw(shuffle);
 
 use base qw(Exporter);
@@ -21,7 +22,7 @@ our @EXPORT = qw(
 
 use Devel::NYTProf::Data;
 use Devel::NYTProf::Reader;
-use Devel::NYTProf::Util qw(html_safe_filename);
+use Devel::NYTProf::Util qw(strip_prefix_from_paths html_safe_filename);
 use Devel::NYTProf::Run qw(perl_command_words);
 
 my $diff_opts = ($Config{osname} eq 'MSWin32') ? '-c' : '-u';
@@ -68,18 +69,12 @@ my $text_extn_info = {
     pf    => { order => 50, tests => 2, },
 };
 
-# having t/* in @INC is necessary for prefix-stripping
-# to reduce test-file names down to the single tokens
-# that are used in the comparison-output files.
-unshift @INC, File::Spec->rel2abs('./t') if -d 't';
 chdir('t') if -d 't';
 
-if ($ENV{PERL_CORE}) {
-    @INC = ('../../../lib/auto', '../../../lib', '.', 'lib');
-} elsif (-d '../blib') {
+if (-d '../blib') {
     unshift @INC, '../blib/arch', '../blib/lib';
 }
-my $bindir = (grep {-d} qw(./blib/script ../blib/script))[0] || do {
+my $bindir      = (grep {-d} qw(./blib/script ../blib/script))[0] || do {
     my $bin = (grep {-d} qw(./bin ../bin))[0]
         or die "Can't find scripts";
     warn "Couldn't find blib/script directory, so using $bin";
@@ -310,9 +305,6 @@ sub run_test_group {
     } );
 
     report_env_influence($group);
-    unlink $profile_datafile;
-    unlink $group."_outdir/*";
-    rmdir $group."_outdir";
 }
 
 
@@ -371,7 +363,6 @@ sub run_test {
         unlink <$outdir/*>;
 
         verify_csv_report($test, $tag, $test_datafile, $outdir);
-        unlink <$outdir/*>;
     }
     elsif ($type eq 'pf') {
         verify_platforms_csv_report($test, $tag, $test_datafile, $outdir);
@@ -449,7 +440,6 @@ sub verify_data {
         $profile->normalize_variables(1); # and options
         dump_profile_to_file($profile, $test.'_new', $test.'_newp');
         is_file_content_same($test.'_new', $test, "$test match generated profile data for $tag");
-        unlink $test.'_new';
     }
 }
 
@@ -458,74 +448,12 @@ sub is_file_content_same {
 
     my @got = slurp_file($got_file); chomp @got;
     my @exp = slurp_file($exp_file); chomp @exp;
-    
-    my $updated = update_file_content_array (\@got);
-    #  Sort the got and exp data if we updated.
-    #  This avoids mismatches due to file sort orders.
-    if ($updated) {
-        @got = sort @got;
-        @exp = sort @exp;
-    }
 
     is_deeply(\@got, \@exp, $testname)
         ? unlink($got_file)
         : diff_files($exp_file, $got_file, $got_file."_patch");
 }
 
-sub update_file_content_array {
-    my $lines = shift;
-    
-    my $file_info_start;
-    foreach my $i (0 .. $#$lines) {
-        next if not $lines->[$i] =~ /^fid_fileinfo/;
-        #  Remove path info that creeps in when run under prove
-        #  Should perhaps use Regexp::Common, or borrow from it.
-        $lines->[$i] =~ s|(\d\t\[ )(\w:/)?([\-\w\s]+/)+|$1|;
-        $file_info_start ||= $i;
-        last if $i > $file_info_start + 4;
-    }
-
-    return if !$file_info_start;
-
-    my $re_eval_id = qr /\(eval ([0-9]+)\)/;
-    my $start_eval_id = 1;
-    #  find the first fid_fileinfo line with an eval in it
-    for my $i ($file_info_start .. 10+$file_info_start) {
-        if ($lines->[$i] =~ $re_eval_id) {
-            $start_eval_id = $1;
-            last;
-        };
-    }
-    return if $start_eval_id <= 1;
-    
-    my $eval_id_offset = $start_eval_id - 1;
-    
-    #  now update the eval IDs for the offset
-    foreach my $i ($file_info_start .. $#$lines) {
-        if (my @matches = ($lines->[$i] =~ m/$re_eval_id/g)) {
-            foreach my $got (@matches) {
-                my $replace = $got - $eval_id_offset;
-                if ($lines->[$i] =~ /test22-strevala.p/) {
-                    #  Correct for the alphabetical ordering
-                    #  as otherwise the 10 is listed before the 9
-                    #  and the line does not match exactly.
-                    #  Clunky, but works for now.
-                    if ($got == 10) {
-                        $replace -= 1;
-                    }
-                    elsif (@matches > 2 && $got == 9) {
-                        $replace += 1;
-                    }
-                }
-                $lines->[$i] =~ s/\(eval $got\)/\(eval $replace\)/;
-            }
-        }
-    }
-
-    #  indicate changes
-    return 1;
-}
-
 
 sub dump_data_to_file {
     my ($profile, $file) = @_;
@@ -562,10 +490,7 @@ sub diff_files {
     # we don't care if this fails, it's just an aid to debug test failures
     # XXX needs to behave better on windows
     my @opts = split / /, $ENV{NYTPROF_DIFF_OPTS} || $diff_opts; # e.g. '-y'
-    #  can sometimes cause issues with cmd shell
-    if ($^O ne 'MSWin32') {
-        system("diff @opts $old_file $new_file 1>&2");
-    }
+    system("diff @opts $old_file $new_file 1>&2");
 }
 
 
@@ -575,7 +500,6 @@ sub verify_calls_report {
     note "generating $got_file";
     run_command("$perl $nytprofcalls $profile_datafile -stable --calls > $got_file");
     is_file_content_same($got_file, $test, "$test match generated calls data for $tag");
-    unlink $got_file;
 }
 
 
@@ -603,7 +527,6 @@ sub verify_csv_report {
 
     my @got      = slurp_file($csvfile);
     my @expected = slurp_file($test);
-    unlink $csvfile;
 
     if ($opts{d}) {
         print "GOT:\n";
@@ -679,7 +602,6 @@ sub verify_csv_report {
         write_out_file($test.'_new', join("\n", @got,''), $test.'_newp');
         diff_files($test, $test.'_new', $test.'_newp');
     };
-    unlink $test.'_newp';
     is(join("\n", @accuracy_errors), '', "$test times should be reasonable");
 }
 
@@ -701,7 +623,7 @@ sub verify_platforms_csv_report {
         $match_result = $match_result && $got =~ m/$_/;
     }
     close (EXPECTED);    
-    unlink $outfile;
+
     ok $match_result, "$outfile file matches $test";
 }
 
